@@ -56,6 +56,8 @@ Later updates (from the source web site):
 
 =item * version 0.68, published on April 3, 2006
 
+=item * version 0.78, published on June 12, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -95,3 +97,4 @@ waldo wally walter wendel wendy will willy wilson wilt_gandhi winston
 world_s_smartest_garbage_man yergi yorgi yugi yvonne zenox zimbu zoltar
 tex flashy petricia tim_zumph earl lefty sourpuss wendel_j_stone_iv
 vijay exactly_man alan andy
+lou mister_serdecisions sandeep
